@@ -1,6 +1,6 @@
 var indexSectionsWithContent =
 {
-  0: "abcdefghilmopstuvw",
+  0: "01abcdefghilmopstuvw",
   1: "l",
   2: "l",
   3: "l",
@@ -8,8 +8,8 @@ var indexSectionsWithContent =
   5: "fl",
   6: "l",
   7: "l",
-  8: "achilmsv",
-  9: "cdi"
+  8: "abcdfhilmopsuv",
+  9: "cdil"
 };
 
 var indexSectionNames =
